@@ -761,7 +761,7 @@ void MainWindow::on_about_triggered()
     msgBox.setWindowTitle(tr("About Theme Customizer"));
     msgBox.setText("Author: D-Iivil - Licence: Freeware & open source (GPL)");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html>Version: 0.9-40<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-41<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
@@ -1061,3 +1061,43 @@ void MainWindow::deletetheme()
 
     }
 }
+
+void MainWindow::on_actionExport_theme_triggered()
+{
+ //   QMaemo5InformationBox::information(this, tr("Select target folder where theme should be exported to"), QMaemo5InformationBox::DefaultTimeout);
+    QString fontdir = QFileDialog::getSaveFileName(this, "Export theme", "/home/user/MyDocs", "Archives (*.tgz)");
+    if (fontdir.isEmpty()) return;
+
+    QString varattu2;
+    varattu2 = tr("Exporting theme");
+    progress2.setLabelText(varattu2);
+    progress2.setWindowModality(Qt::WindowModal);
+    progress2.setWindowTitle(varattu2);
+    progress2.setCancelButton(0);
+    QStringList arguments2;
+    arguments2 << "exporttheme" << fontdir;
+    QProcess *process2 = new QProcess(this);
+    connect(process2, SIGNAL(finished(int)), this, SLOT(process2Finished(int)));
+    process2->start("/sbin/launchcustomizer", arguments2);
+    progress2.show();
+}
+
+void MainWindow::on_actionImport_theme_triggered()
+{
+    QMaemo5InformationBox::information(this, tr("Select .tgz file to import"), QMaemo5InformationBox::DefaultTimeout);
+    QString fontdir = QFileDialog::getOpenFileName(this, "Import theme", "/home/user/MyDocs", "Archives (*.tgz)");
+    if (fontdir.isEmpty()) return;
+
+    QString varattu2;
+    varattu2 = tr("Importing theme");
+    progress2.setLabelText(varattu2);
+    progress2.setWindowModality(Qt::WindowModal);
+    progress2.setWindowTitle(varattu2);
+    progress2.setCancelButton(0);
+    QStringList arguments2;
+    arguments2 << "importtheme" << fontdir;
+    QProcess *process2 = new QProcess(this);
+    connect(process2, SIGNAL(finished(int)), this, SLOT(process2Finished(int)));
+    process2->start("/sbin/launchcustomizer", arguments2);
+    progress2.show();
+}
