@@ -77,6 +77,8 @@ private:
     managethemes* ManThemeWin;
 
 private slots:
+    void on_actionImport_theme_triggered();
+    void on_actionExport_theme_triggered();
     void deletetheme();
     void on_actionDelete_saved_themes_triggered();
     void on_actionSave_as_new_theme_triggered();
