@@ -8,6 +8,26 @@
         <source>Theme Customizer</source>
         <translation>Customiser le thème</translation>
     </message>
+    <message>
+        <source>Export theme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Import theme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Exporting theme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select .tgz file to import</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Importing theme</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="mainwindow.ui" line="0"/>
         <source>Restore theme files</source>
@@ -16,32 +36,32 @@
     <message>
         <location filename="mainwindow.ui" line="0"/>
         <source>Delete saved themes</source>
-        <translation type="unfinished"></translation>
+        <translation>Effacer les thèmes sauvegarder</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Selected theme is currently in use!</source>
-        <translation type="unfinished"></translation>
+        <translation>Séléctionner le thème courrant!</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>You can&apos;t delete a theme that&apos;s currently active.</source>
-        <translation type="unfinished"></translation>
+        <translation>Vous ne pouvez pas effacer le thème courrant.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Delete theme?</source>
-        <translation type="unfinished"></translation>
+        <translation>Effacer le thème ?</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Are you sure you want to delete this theme?</source>
-        <translation type="unfinished"></translation>
+        <translation>Etes-vous sur de vouloir effacer ce thème?</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Theme deleted.</source>
-        <translation type="unfinished"></translation>
+        <translation>Thème effacer.</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="0"/>
@@ -71,7 +91,7 @@
     <message>
         <location filename="mainwindow.ui" line="0"/>
         <source>Save as new theme</source>
-        <translation>Sauvegarder comme un  nouveau thème</translation>
+        <translation>Créer comme un  nouveau thème</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
@@ -544,7 +564,7 @@ déverrouillage</translation>
     <message>
         <location filename="savenewtheme.ui" line="0"/>
         <source>Save theme as...</source>
-        <translation>Sauvegarder le thème sous...</translation>
+        <translation>Enregistrer le thème sous...</translation>
     </message>
     <message>
         <location filename="savenewtheme.ui" line="0"/>
@@ -557,17 +577,17 @@ déverrouillage</translation>
     <message>
         <location filename="managethemes.ui" line="0"/>
         <source>Select theme:</source>
-        <translation type="unfinished"></translation>
+        <translation>Sélectionner le thème:</translation>
     </message>
     <message>
         <location filename="managethemes.ui" line="0"/>
         <source>Delete</source>
-        <translation type="unfinished"></translation>
+        <translation>Effacer</translation>
     </message>
     <message>
         <location filename="managethemes.cpp" line="0"/>
         <source>No themes created by Theme Customizer found</source>
-        <translation type="unfinished"></translation>
+        <translation>Aucun thème créer avec Theme Customizer trouvé</translation>
     </message>
 </context>
 </TS>
